package kali

import (
	"fmt"
	"log"
	"strings"

	"git.hyperreal.coffee/go-torrent-helper/common"
	"github.com/PuerkitoBio/goquery"
	"github.com/hekmon/transmissionrpc"
)

type Kali struct {
	NameSubstr string
	Relver     string
	URL        string
}

func (k Kali) AddNewTorrents(transmissionbt *transmissionrpc.Client) error {
	// Send HTTP GET request and receive response
	k.URL = fmt.Sprintf("https://cdimage.kali.org/kali-%s/", k.Relver)
	respBody, err := common.GetResponse(k.URL)
	if err != nil {
		return err
	}

	// Get a goquery doc from response body
	doc, err := goquery.NewDocumentFromReader(respBody)
	if err != nil {
		return err
	}

	// Extract torrent URLs from web page source
	var torrentURLs []string
	doc.Find("a").Each(func(i int, s *goquery.Selection) {
		if strings.Contains(s.Text(), ".torrent") {
			torrentURLs = append(torrentURLs, fmt.Sprintf("%s/kali-linux-%s-%s.torrent", k.URL, k.Relver, s.Text()))
		}
	})

	// Add torrents to Transmission instance
	for _, torrentURL := range torrentURLs {
		torrent, err := transmissionbt.TorrentAdd(&transmissionrpc.TorrentAddPayload{
			Filename: &torrentURL,
		})
		if err != nil {
			return err
		}

		log.Printf("%s added\n", *torrent.Name)
	}

	return nil
}

func (k Kali) RemoveOldTorrents(transmissionbt *transmissionrpc.Client) error {
	if err := common.RemoveTorrents(k.NameSubstr, k.Relver, transmissionbt); err != nil {
		return err
	}

	return nil
}
